cli

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: MPL-2.0 Imports: 30 Imported by: 0

Documentation

Overview

Package cli provides the CLI command definitions and Cobra setup.

Index

Constants

This section is empty.

Variables

var ErrDaemonNotRunning = errors.New("daemon is not running")

ErrDaemonNotRunning is returned by status when the daemon is not running. The root command can check for this to set exit code 1.

var ErrValidationFailed = errors.New("recurfile validation failed")

ErrValidationFailed is returned when recurfile validation fails.

var Version = buildinfo.Version("0.1.0-alpha")

Version is the CLI version: the release-injected tag, else the module version from `go install`, else this development default.

Functions

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd creates the root `recur` command.

Types

This section is empty.

Jump to